@@ -3,7 +3,7 @@ use warnings;
 package Test::WSNCC::Command::blort;
 use Test::WSNCC -command;
 
-sub run {
+sub execute {
   my ($self, $opt, $args) = @_;
   return $opt;
 }
