@@ -3,7 +3,7 @@ use warnings;
 package Test::WithSetup::Command::bertie;
 use Test::WithSetup -command;
 
-sub run {
+sub execute {
   my ($self, $opt, $args) = @_;
   return xyzzy foo => 'bar';
 }
